@@ -15,7 +15,7 @@ class SceneBase(BaseModel):
 
 class SceneSummary(SceneBase):
     scene_name: str
-    tile: str
+    tile: str = None
     tile_intersection_w_aoi: Optional[float]
     date_time: datetime
 
@@ -26,6 +26,16 @@ class SceneSummary(SceneBase):
     overall_data_coverage: Optional[float]
     overall_data_perc_of_aoi:  Optional[float]
     scene_grade:  Optional[float]
+        
+    def __init__(self, **data):
+        super().__init__(**data)
+        self.tile = self.get_tile_name_from_scene()
+    
+    def get_tile_name_from_scene(self):
+        name = self.scene_id.split("_")[1]
+        if len(name) != 5:
+            name = "0" + name
+        return name
 
 
 
